<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 02/12/2004 *
 * ================                             Last change: 11/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-theme_import.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Import of new themes                             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Importieren von neuen Themes                     *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!IS_ADMIN())) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} elseif (!EXT_IS_ACTIVE("theme")) {
	addFatalMessage(__FILE__, __LINE__, getMessage('EXTENSION_PROBLEM_EXT_INACTIVE'), "theme");
	return;
}

// Add description as navigation point
ADD_DESCR("admin", __FILE__);

// Switch to testing mode
$THEME_MODE = "test";

// Import selected theme if not present
if (REQUEST_ISSET_POST(('theme'))) {
	// Check if theme is there
	if (!THEME_CHECK_EXIST(REQUEST_POST('theme'))) {
		// Import theme
		$INC = sprintf("theme/%s/theme.php", SQL_ESCAPE(REQUEST_POST('theme')));
		if (INCLUDE_READABLE($INC)) {
			// Load the theme header file
			LOAD_INC($INC);

			// Register it ith the exchange
			SQL_QUERY_ESC("INSERT INTO `{!_MYSQL_PREFIX!}_themes` (`theme_path`, `theme_active`, `theme_ver`, `theme_name`)
VALUES ('%s','N','%s','%s')",
				array(REQUEST_POST('theme'), $THEME_VERSION, $THEME_NAME), __FILE__, __LINE__);

			// Destroy cache
			REBUILD_CACHE("themes", "them");

			// Prepare message
			$msg = ADMIN_THEME_IMPORTED_1.REQUEST_POST('theme').ADMIN_THEME_IMPORTED_2;
		} else {
			// Include file not found!
			$msg = ADMIN_THEME_INC_404_1.REQUEST_POST('theme').ADMIN_THEME_INC_404_2;
		}
	} else {
		// Theme already imported
		$msg = ADMIN_THEME_ALREADY_1.REQUEST_POST('theme').ADMIN_THEME_ALREADY_2;
	}

	// Output message
	LOAD_TEMPLATE("admin_settings_saved", false, $msg);
} // END - if

// Initialize array
$THEMES = array(
	'theme_unix'   => array(), // Unix name from filesystem
	'theme_name'   => array(), // Title
	'theme_author' => array(), // Theme author's name
	'theme_email'  => array(), // Author's email address
	'theme_url'    => array(), // URL were you can download it from
	'theme_ver'    => array(), // Version number of theme
);

// Read directory "themes"
$handle = opendir(constant('PATH')."theme/") or mxchange_die("Cannot read themes dir!");
while ($dir = readdir($handle)) {
	// Construct absolute theme.php file name
	$INC = sprintf("theme/%s/theme.php", $dir);

	// Test it...
	if (($dir != ".") && ($dir != "..") && (INCLUDE_READABLE($INC))) {
		// Found a valid directory so let's load it's theme.php file
		LOAD_INC($INC);

		// Add found theme to array
		$THEMES['theme_unix'][]   = $dir;
		$THEMES['theme_name'][]   = $THEME_NAME;
		$THEMES['theme_author'][] = $THEME_AUTHOR;
		$THEMES['theme_email'][]  = $THEME_EMAIL;
		$THEMES['theme_url'][]    = $THEME_URL;
		$THEMES['theme_ver'][]    = $THEME_VERSION;
	} // END - if
} // END - while

// Close directory
closedir($handle);

// Sort array by Uni* name
array_pk_sort($THEMES, array("theme_name"));

// Generate output lines for the template
$OUT = ""; $SW = 2;
foreach ($THEMES['theme_unix'] as $key => $unix) {
	// Already installed is default
	$FOUND = "<div class=\"admin_note\">{--ADMIN_THEME_ALREADY_INSTALLED--}</div>";

	// Check if current theme is already imported or not
	if (!THEME_CHECK_EXIST($unix)) {
		// Theme not installed
		$FOUND = LOAD_TEMPLATE("admin_theme_import_form", true, $unix);
	} // END - if

	// Prepare content
	$content = array(
		'sw'      => $SW,
		'unix'    => $unix,
		'name'    => $THEMES['theme_name'][$key],
		'email'   => $THEMES['theme_email'][$key],
		'author'  => $THEMES['theme_author'][$key],
		'link'    => DEREFERER($THEMES['theme_url'][$key]),
		'url'     => $THEMES['theme_url'][$key],
		'version' => $THEMES['theme_ver'][$key],
		'form'    => $FOUND
	);

	// Add row template
	$OUT .= LOAD_TEMPLATE("admin_theme_import_row", true, $content);

	// Switch color
	$SW = 3 - $SW;
} // END - foreach

if (empty($OUT)) {
	// No themes found???
	$OUT .= LOAD_TEMPLATE("admin_theme_import_none", true, LOAD_TEMPLATE("admin_settings_saved", true, getMessage('ADMIN_NO_THEMES_FOUND')));
} // END - if

// Set the generated list
define('__THEME_LIST', $OUT);

// Load template
LOAD_TEMPLATE("admin_theme_import");

//
?>
